<?php
  /* vim: set expandtab tabstop=4 softtabstop=4 shiftwidth=4:
  Codificación: UTF-8
  +----------------------------------------------------------------------+
  | Elastix version 2.3.0-12                                               |
  | http://www.elastix.org                                               |
  +----------------------------------------------------------------------+
  | Copyright (c) 2006 Palosanto Solutions S. A.                         |
  +----------------------------------------------------------------------+
  | Cdla. Nueva Kennedy Calle E 222 y 9na. Este                          |
  | Telfs. 2283-268, 2294-440, 2284-356                                  |
  | Guayaquil - Ecuador                                                  |
  | http://www.palosanto.com                                             |
  +----------------------------------------------------------------------+
  | The contents of this file are subject to the General Public License  |
  | (GPL) Version 2 (the "License"); you may not use this file except in |
  | compliance with the License. You may obtain a copy of the License at |
  | http://www.opensource.org/licenses/gpl-license.php                   |
  |                                                                      |
  | Software distributed under the License is distributed on an "AS IS"  |
  | basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See  |
  | the License for the specific language governing rights and           |
  | limitations under the License.                                       |
  +----------------------------------------------------------------------+
  | The Original Code is: Elastix Open Source.                           |
  | The Initial Developer of the Original Code is PaloSanto Solutions    |
  +----------------------------------------------------------------------+
  $Id: index.php,v 1.1 2013-06-02 01:06:33 Alberto Santos asantos@palosanto.com Exp $ */
//include elastix framework
include_once "libs/paloSantoGrid.class.php";
include_once "libs/paloSantoForm.class.php";

function _moduleContent(&$smarty, $module_name)
{
    //include module files
    include_once "modules/$module_name/configs/default.conf.php";
    include_once "modules/$module_name/libs/paloSantoOrkestal.class.php";

    //include file language agree to elastix configuration
    //if file language not exists, then include language by default (en)
    $lang=get_language();
    $base_dir=dirname($_SERVER['SCRIPT_FILENAME']);
    $lang_file="modules/$module_name/lang/$lang.lang";
    if (file_exists("$base_dir/$lang_file")) include_once "$lang_file";
    else include_once "modules/$module_name/lang/en.lang";

    //global variables
    global $arrConf;
    global $arrConfModule;
    global $arrLang;
    global $arrLangModule;
    $arrConf = array_merge($arrConf,$arrConfModule);
    $arrLang = array_merge($arrLang,$arrLangModule);

    //folder path for custom templates
    $templates_dir=(isset($arrConf['templates_dir']))?$arrConf['templates_dir']:'themes';
    $local_templates_dir="$base_dir/modules/$module_name/".$templates_dir.'/'.$arrConf['theme'];

    //conexion resource
    $pDB = new paloDB($arrConf['dsn_conn_database']);

    //actions
    $action = getAction();
    $content = "";

    switch($action){
        case "submit":
            $content = saveActivation($smarty, $module_name, $local_templates_dir, $pDB, $arrConf);
            break;
	case "toStore":
	    $content = redirectToStore($smarty, $module_name, $local_templates_dir, $pDB, $arrConf);
        default: // view_form
            $content = viewFormActivation($smarty, $module_name, $local_templates_dir, $pDB, $arrConf);
            break;
    }
    return $content;
}

function viewFormActivation($smarty, $module_name, $local_templates_dir, &$pDB, $arrConf, $error=FALSE)
{
    $pActivation = new paloSantoOrkestal($pDB);
    $license = $pActivation->getLicense();
    $enterlic = $pActivation->isReadyToEnterLic();
    if(!isset($license) || !isset($enterlic)){
	$smarty->assign("mb_title", _tr("ERROR"));
	$smarty->assign("mb_message", _tr("An error ocurred in database"));
	return "";
    }
    $smarty->assign("enterlic",$enterlic);
    $blocks = array(0,1,2,3,4,5,6,7); //8 license blocks
    $smarty->assign("blocks",$blocks);
    $smarty->assign("LICENSE",_tr("License Key"));
    $smarty->assign("newversion",0);
    if(empty($license)){
	$smarty->assign("ACTIVATED",_tr("Not Activated"));
	if(!$enterlic)
	    $smarty->assign("INFO",_tr("To activate the trial ")."<a href='?menu=$module_name&action=toStore'>"._tr("click here")."</a>");
	else{
	    if($error)
		$smarty->assign("INFO","<font color=red>"._tr("Error! ")."</font>"._tr("please enter the key again and click on Submit"));
	    else
	    	$smarty->assign("INFO",_tr("To activate the trial enter the key and click on Submit"));
	}
    }
    else{
	$license = explode("-",$license);
	if(!validateLicense($license)){
		$smarty->assign("INFO","<font color=red>"._tr("Error! ")."</font>"._tr("please enter the key again and click on Submit"));
		$smarty->assign("enterlic",TRUE);
	}
	else{
		$smarty->assign("INFO",_tr("Orkestal is Activated"));
		switch($license[2][0]){
			case "T":
				if($enterlic)
					$smarty->assign("INFO",_tr("To activate the Standard version enter the key and click on Submit"));
				else
					$smarty->assign("newversion",1);
				$smarty->assign("GETVERSION",_tr("Get the standard version now!"));
				$expire = strtotime(substr($license[6],2)."-".substr($license[6],0,2)."-20".substr($license[5],2)); //TODO: This will be wrong when we reach the year 2100
				$now = strtotime(date("d-m-Y"));
				$diff = $expire - $now;
				if($diff <= 0){
					$smarty->assign("ACTIVATED","Lite");
					if(!$enterlic)
						$smarty->assign("TIME",_tr("Your trial period is over"));
				}
				else{
					$smarty->assign("ACTIVATED",_tr("Trial Version"));
					$days = $diff/86400;
					$smarty->assign("TIME",_tr("Your trial time period has ").$days._tr(" days left"));
				}
				break;
			case "S":
				$smarty->assign("ACTIVATED",_tr("Standard"));
				$smarty->assign("INFO",_tr("Orkestal is Activated"));
				$smarty->assign("COMINGSOON",_tr("ORKESTAL Professional version soon!"));
				break;
		}
	}
    }
    $oForm = new paloForm($smarty,array());

    $smarty->assign("ORKESTAL",_tr("Orkestal"));
    $smarty->assign("MODULE_NAME",$module_name);
    $smarty->assign("SUBMIT",_tr("Submit"));
    $smarty->assign("LINK",_tr("Download the desktop terminal here"));
    $smarty->assign("INFO_LICENSE",_tr("The license key is the activation key provided according to the type of license acquired. You must enter it on the boxes and click on submit"));
    $smarty->assign("BUY",_tr("BUY"));
    $smarty->assign("icon","/modules/$module_name/images/orkestal_ico.png");	
    $htmlForm = $oForm->fetchForm("$local_templates_dir/form.tpl",_tr("License"));
    $content = "<form  method='POST' style='margin-bottom:0;' action='?menu=$module_name'>".$htmlForm."</form>";

    return $content;
}

function redirectToStore($smarty, $module_name, $local_templates_dir, &$pDB, $arrConf)
{ 
    $pActivation = new paloSantoOrkestal($pDB);
    $elastixKey = $pActivation->getElastixKey();
    if(!isset($elastixKey) || empty($elastixKey)){
	$smarty->assign("mb_title", _tr("ERROR"));
        $smarty->assign("mb_message", _tr("Your elastix is not registered, please register your Elastix before continuing"));
	return  viewFormActivation($smarty, $module_name, $local_templates_dir, $pDB, $arrConf);
    }	
    $change = $pActivation->changeEnterLic(1);
    if(!isset($change)){
	$smarty->assign("mb_title", _tr("ERROR"));
        $smarty->assign("mb_message", _tr("An error ocurred in database"));
	return  viewFormActivation($smarty, $module_name, $local_templates_dir, $pDB, $arrConf);
    }
    header("Location: http://store.palosanto.com/index.php/elastix-addons/elastix-orkestal.html?addon=elastix-orkestal&serverkey=$elastixKey&referer=https://{$_SERVER["SERVER_ADDR"]}/index.php?menu=$module_name");
    return "";
}

function validateLicense($license)
{
	if($license[0] != "ES01" || ($license[2][0] != "T" && $license[2][0] != "L" && $license[2][0] != "S") || !preg_match("/^\d*$/",substr($license[5],2).$license[6]))
		return FALSE;
	else
		return TRUE;
}

function saveActivation($smarty, $module_name, $local_templates_dir, &$pDB, $arrConf)
{
    $pActivation = new paloSantoOrkestal($pDB);
    $licenseBlocks = array();
    for($i=0;$i<=7;$i++){
	$licenseBlocks[$i] = getParameter("block".$i);
	if(!isset($licenseBlocks[$i]) || strlen($licenseBlocks[$i]) != 4)
		return  viewFormActivation($smarty, $module_name, $local_templates_dir, $pDB, $arrConf, TRUE);
    }
    if(!validateLicense($licenseBlocks))
	return  viewFormActivation($smarty, $module_name, $local_templates_dir, $pDB, $arrConf, TRUE);
    $license = implode("-",$licenseBlocks);
    $save = $pActivation->saveLicense($license);
    if(!isset($save)){
	$smarty->assign("mb_title", _tr("ERROR"));
        $smarty->assign("mb_message", _tr("An error ocurred in database"));
    }
    $change = $pActivation->changeEnterLic(0);
    if(!isset($change)){
        $smarty->assign("mb_title", _tr("ERROR"));
        $smarty->assign("mb_message", _tr("An error ocurred in database"));
    }
    return  viewFormActivation($smarty, $module_name, $local_templates_dir, $pDB, $arrConf);
}

function getAction()
{
    if(getParameter("action") == "toStore")
	return "toStore";
    elseif(getParameter("submit"))
	return "submit";
    else
        return "view_form";
}
?>
